@@ -1,7 +1,7 @@
-from .tools.helpers import RangeDict
-from .uniBlockData import uniBlocks
+import jkUnicode.tools.helpers
+from jkUnicode.uniBlockData import uniBlocks
 
-uniBlockToName = RangeDict(uniBlocks)
+uniBlockToName = jkUnicode.tools.helpers.RangeDict(uniBlocks)
 
 # The reverse mapping of names to blocks
 uniNameToBlock = {}
